@@ -8,6 +8,7 @@ from dataquality.clients.api import ApiClient
 from dataquality.core._config import config
 from dataquality.schemas import RequestType, Route
 from dataquality.schemas.job import JobName
+from dataquality.schemas.task_type import TaskType
 from dataquality.utils.dq_logger import DQ_LOG_FILE_HOME, upload_dq_log_file
 from dataquality.utils.helpers import check_noop
 from dataquality.utils.thread_pool import ThreadPoolManager
@@ -17,22 +18,31 @@ api_client = ApiClient()
 
 
 @check_noop
-def finish() -> Optional[Dict[str, Any]]:
+def finish(
+    last_epoch: Optional[int] = None, wait: bool = True
+) -> Optional[Dict[str, Any]]:
     """
     Finishes the current run and invokes a job
+
+    :param last_epoch: If set, only epochs up to this value will be uploaded/processed
+        This is inclusive, so setting last_epoch to 5 would upload epochs 0,1,2,3,4,5
+    :param wait: If true, after uploading the data, this will wait for the
+        run to be processed by the Galileo server. If false, you can manually wait
+        for the run by calling `dq.wait_for_run()` Default True
     """
     ThreadPoolManager.wait_for_threads()
     assert config.current_project_id, "You must have an active project to call finish"
     assert config.current_run_id, "You must have an active run to call finish"
+    assert config.task_type, "You must have a task type to call finish"
     data_logger = dataquality.get_data_logger()
     data_logger.validate_labels()
 
     _version_check()
 
     if data_logger.non_inference_logged():
-        _reset_run(config.current_project_id, config.current_run_id)
+        _reset_run(config.current_project_id, config.current_run_id, config.task_type)
 
-    data_logger.upload()
+    data_logger.upload(last_epoch)
     data_logger._cleanup()
     upload_dq_log_file()
 
@@ -40,6 +50,7 @@ def finish() -> Optional[Dict[str, Any]]:
         project_id=str(config.current_project_id),
         run_id=str(config.current_run_id),
         labels=data_logger.logger_config.labels,
+        task_type=config.task_type.value,
         tasks=data_logger.logger_config.tasks,
     )
     if data_logger.logger_config.inference_logged:
@@ -56,6 +67,8 @@ def finish() -> Optional[Dict[str, Any]]:
     )
     # Reset all config variables
     data_logger.logger_config.reset()
+    if wait:
+        wait_for_run()
     return res
 
 
@@ -93,7 +106,9 @@ def get_run_status(
 
 
 @check_noop
-def _reset_run(project_id: UUID4, run_id: UUID4) -> None:
+def _reset_run(
+    project_id: UUID4, run_id: UUID4, task_type: Optional[TaskType] = None
+) -> None:
     """Clear the data in minio before uploading new data
 
     If this is a run that already existed, we want to fully overwrite the old data.
@@ -101,7 +116,7 @@ def _reset_run(project_id: UUID4, run_id: UUID4) -> None:
     give it a new ID
     """
     old_run_id = run_id
-    api_client.reset_run(project_id, old_run_id)
+    api_client.reset_run(project_id, old_run_id, task_type)
     project_dir = (
         f"{dataquality.get_data_logger().LOG_FILE_DIR}/{config.current_project_id}"
     )
