@@ -68,10 +68,12 @@ def upload_dq_log_file() -> None:
     assert config.current_project_id and config.current_run_id
     obj_store = ObjectStore()
     obj_name = dq_log_object_name(config.current_project_id, config.current_run_id)
-    obj_store.create_project_run_object(
-        object_name=obj_name, file_path=dq_log_file_path(), content_type="text/plain"
-    )
-    remove_dq_log_file()
+    file_path = dq_log_file_path()
+    if os.path.isfile(file_path):
+        obj_store.create_project_run_object(
+            object_name=obj_name, file_path=file_path, content_type="text/plain"
+        )
+        remove_dq_log_file()
 
 
 @check_noop
@@ -83,6 +85,8 @@ def get_dq_log_file(
     )
     log_object = dq_log_object_name(pid, rid)
     log_file_path = dq_log_file_path(rid)
+    log_file_dir = os.path.split(log_file_path)[0]
+    os.makedirs(log_file_dir, exist_ok=True)
     obj_store = ObjectStore()
     obj_store.download_file(object_name=log_object, file_path=log_file_path)
     print(f"Your logfile has been written to {log_file_path}")
